<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [useFirestoreConnect](#usefirestoreconnect)

## useFirestoreConnect

-   **See: <http://docs.react-redux-firebase.com/history/v3.0.0/docs/api/useFirestoreConnect.html>**

React hook that automatically listens/unListens
to provided Cloud Firestore paths. Make sure you have required/imported
Cloud Firestore, including it's reducer, before attempting to use.
**Note** Populate is not yet supported.

**Parameters**

-   `queriesConfigs` **([object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object) \| [string](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String) \| [Array](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array) \| [Function](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function))** An object, string,
    or array of object or string for paths to sync from firestore. Can also be
    a function that returns the object, string, or array of object or string.

**Examples**

_Basic_

```javascript
import React from 'react'
import { map } from 'lodash'
import { useSelector } from 'react-redux'
import { useFirebaseConnect } from 'react-redux-firebase'

function TodosList() {
  useFirebaseConnect('todos') // sync todos collection from Firestore into redux
  const todos = useSelector(state => state.firebase.data.todos)
  return (
    <ul>
      {map(todos, (todo, todoId) => (
       <li>id: {todoId} todo: {JSON.stringify(todo)}</li>
      ))}
   </ul>
  )
}
export default TodosList
```

_Object as query_

```javascript
import React, { useMemo } from 'react'
import { get } from 'lodash'
import { connect } from 'react-redux'
import { useFirebaseConnect } from 'react-redux-firebase'

function TodoItem({ todoId, todoData }) {
  useFirebaseConnect(() => ({
    collection: 'todos',
    doc: todoId
  }), [todoId]) // include dependency in the hook

  return <div>{JSON.stringify(todoData)}</div>
}

// pass todo data from redux as props.todosList
export default compose(
  connect((state) => ({
    todoData: get(state, ['firestore', 'data', 'todos', todoId])
  })
)(TodoItem)
```
